##  Related Information
  * [IT Component Modeling Guidelines](https://help.sap.com/docs/leanix/ea/it-component-modeling-guidelines?locale=en-US&state=PRODUCTION&version=CLOUD "Learn how to model IT components. This includes best practices and applicable use cases, and common antipatterns.")
  * [Initiative Modeling Guidelines](https://help.sap.com/docs/leanix/ea/initiative-modeling-guidelines?locale=en-US&state=PRODUCTION&version=CLOUD "Learn how to model initiatives. This includes best practices and applicable use cases, and common antipatterns.")


YesNo
Send
